@@ -1,7 +1,7 @@
 
 from db import connection
 
-version = "0.6"
+version = "0.7"
 __doc__ = """
 
     pgwrap - simple PostgreSQL database wrapper
@@ -27,7 +27,7 @@ __doc__ = """
               context handler (also available as stand-alone methods which
               create an implicit cursor for simple queries)
         * Query results as dict (using psycopg2.extras.DictCursor)
-        * Prepared statement support
+        * Callable prepared statements
         * Logging support
 
     Basic usage
@@ -54,7 +54,7 @@ __doc__ = """
     implicit cursor).
 
     The intention is that a single instance of this class is created at
-    application start up and 
+    application start up.
 
     Cursor
     ------
@@ -82,7 +82,6 @@ __doc__ = """
         query_one       - execute SQL query and fetch first result
         query_dict      - execute SQL query and return results as dict
                           keyed on specified key (which should be unique)
-        callproc        - Call stored procedure
         commit          - Commit transaction (called implicitly on exiting
                           context handler)
         rollback        - Rollback transaction
@@ -175,18 +174,36 @@ __doc__ = """
 
         Prepared statements can be created using the
 
-            connection.prepare(stmt,params,name) 
+            connection.prepare(stmt,params,name,call_type) 
 
-        method where 'stmt' is the prapared statement (with parameters identified
-        in the statement using the psql $1,$2... notation), 'params' is a list of optional
-        parameter types (usually not needed - infered by psql), and 'name' is the 
-        name of the prepared statement (usually autogenerated). The method returns
-        a PreparedStatement object which can be used instead of an sql statement in 
-        the connection.execute and connection.query methods.
+            stmt      : prepared statement (with parameters identified 
+                        in the statement using the psql $1,$2... notation)
+            params    : list of optional parameter types (usually not 
+                        needed - infered by psql)
+            name      : name for the prepared statement (usually
+                        autogenerated)
+            call_type : method used when instance called as method
+                        (defaults to 'query')
+
+        The constructor returns a PreparedStatement object which can be used
+        instead of an sql statement in the connection.execute and
+        connection.query_xxx methods.
 
         >>> p = db.prepare('UPDATE t1 SET name = $2 WHERE id = $1')
         PREPARE _pstmt_001  AS UPDATE t1 SET name = $2 WHERE id = $1
-        >>> db.execute(p,(1,'xxx'))
+        >>> with db.cursor() as c:
+        ...     c.execute(p,(1,'xxx'))
+        EXECUTE _pstmt_001 (1,'xxx')
+
+        The PreparedStatement object can also be called directly using the
+        execute/query/query_one/query_dict methods. The instance is also
+        directly callable using the method type identified in 'call_type'
+
+        >>> p = db.prepare('UPDATE t1 SET name = $2 WHERE id = $1')
+        PREPARE _pstmt_001  AS UPDATE t1 SET name = $2 WHERE id = $1
+        >>> p.execute(1,'xxx')
+        EXECUTE _pstmt_001 (1,'xxx')
+        >>> p(1,'xxx')
         EXECUTE _pstmt_001 (1,'xxx')
 
     Logging
@@ -215,6 +232,7 @@ __doc__ = """
         *   0.4     21-10-2012  Add logging support 
         *   0.5     22-12-2012  Refactor connection class / remove globals
         *   0.6     23-12-2012  Add support for prepared statements
+        *   0.7     26-12-2012  Add callable prepared statements & named cursor
 
     Author
     ------
@@ -228,7 +246,3 @@ __doc__ = """
 
 """
 
-if __name__ == '__main__':
-    import code,doctest,sys
-    doctest.testmod(optionflags=doctest.ELLIPSIS)
-
